.. _scripting_examples:

Examples
========

A collection of examples are presented to supplement the tutorial. The
examples below are identical to the Jupyter Notebook in the ``examples``
folder of the repository
`here <https://github.com/CURENT/ams/tree/master/examples>`__.

.. toctree::
   :maxdepth: 2
   :caption: Scripting

   ../_examples/ex1.ipynb
   ../_examples/ex2.ipynb
   ../_examples/ex3.ipynb
   ../_examples/ex4.ipynb
   ../_examples/ex5.ipynb
   ../_examples/ex6.ipynb
   ../_examples/ex7.ipynb
   ../_examples/ex8.ipynb

.. toctree::
   :maxdepth: 2
   :caption: Demonstration

   ../_examples/demo/demo_ESD1.ipynb
   ../_examples/demo/demo_AGC.ipynb
   ../_examples/demo/demo_debug.ipynb
   ../_examples/demo/demo_mat.ipynb